package org.apache.bcel.classfile;

import java.io.DataInput;
import java.io.DataOutputStream;
import java.io.IOException;
import java.util.Arrays;
import java.util.Iterator;
import java.util.stream.Stream;

/* loaded from: org_apache_bcel_classfile.jar:org/apache/bcel/classfile/LineNumberTable.class */
public final class LineNumberTable extends Attribute implements Iterable<LineNumber> {
    private static final int MAX_LINE_LENGTH = 72;
    private LineNumber[] lineNumberTable;

    /* JADX INFO: Access modifiers changed from: package-private */
    public LineNumberTable(int nameIndex, int length, DataInput input, ConstantPool constantPool) throws IOException {
        this(nameIndex, length, (LineNumber[]) null, constantPool);
        int lineNumberTableLength = input.readUnsignedShort();
        this.lineNumberTable = new LineNumber[lineNumberTableLength];
        for (int i = 0; i < lineNumberTableLength; i++) {
            this.lineNumberTable[i] = new LineNumber(input);
        }
    }

    public LineNumberTable(int nameIndex, int length, LineNumber[] lineNumberTable, ConstantPool constantPool) {
        super((byte) 4, nameIndex, length, constantPool);
        this.lineNumberTable = lineNumberTable;
    }

    public LineNumberTable(LineNumberTable c) {
        this(c.getNameIndex(), c.getLength(), c.getLineNumberTable(), c.getConstantPool());
    }

    @Override // org.apache.bcel.classfile.Attribute, org.apache.bcel.classfile.Node
    public void accept(Visitor v) {
        v.visitLineNumberTable(this);
    }

    @Override // org.apache.bcel.classfile.Attribute
    public Attribute copy(ConstantPool constantPool) {
        LineNumberTable c = (LineNumberTable) clone();
        c.lineNumberTable = new LineNumber[this.lineNumberTable.length];
        Arrays.setAll(c.lineNumberTable, i -> {
            return this.lineNumberTable[i].copy();
        });
        c.setConstantPool(constantPool);
        return c;
    }

    @Override // org.apache.bcel.classfile.Attribute
    public void dump(DataOutputStream file) throws IOException {
        super.dump(file);
        file.writeShort(this.lineNumberTable.length);
        for (LineNumber lineNumber : this.lineNumberTable) {
            lineNumber.dump(file);
        }
    }

    public LineNumber[] getLineNumberTable() {
        return this.lineNumberTable;
    }

    public int getSourceLine(int pos) {
        int l = 0;
        int r = this.lineNumberTable.length - 1;
        if (r < 0) {
            return -1;
        }
        int minIndex = -1;
        int min = -1;
        do {
            int i = (l + r) >>> 1;
            int j = this.lineNumberTable[i].getStartPC();
            if (j == pos) {
                return this.lineNumberTable[i].getLineNumber();
            }
            if (pos < j) {
                r = i - 1;
            } else {
                l = i + 1;
            }
            if (j < pos && j > min) {
                min = j;
                minIndex = i;
            }
        } while (l <= r);
        if (minIndex < 0) {
            return -1;
        }
        return this.lineNumberTable[minIndex].getLineNumber();
    }

    public int getTableLength() {
        if (this.lineNumberTable == null) {
            return 0;
        }
        return this.lineNumberTable.length;
    }

    @Override // java.lang.Iterable
    public Iterator<LineNumber> iterator() {
        return Stream.of((Object[]) this.lineNumberTable).iterator();
    }

    public void setLineNumberTable(LineNumber[] lineNumberTable) {
        this.lineNumberTable = lineNumberTable;
    }

    @Override // org.apache.bcel.classfile.Attribute
    public String toString() {
        StringBuilder buf = new StringBuilder();
        StringBuilder line = new StringBuilder();
        String newLine = System.getProperty("line.separator", "\n");
        for (int i = 0; i < this.lineNumberTable.length; i++) {
            line.append(this.lineNumberTable[i].toString());
            if (i < this.lineNumberTable.length - 1) {
                line.append(", ");
            }
            if (line.length() > MAX_LINE_LENGTH && i < this.lineNumberTable.length - 1) {
                line.append(newLine);
                buf.append((CharSequence) line);
                line.setLength(0);
            }
        }
        buf.append((CharSequence) line);
        return buf.toString();
    }
}
